@@ -1,12 +1,17 @@
 #' Establish a connection to the DataRobot modeling engine
 #'
-#' This function initializes a DataRobot session. If a (YAML) config file (with keys for endpoint
-#' and token) is placed at $HOME/.config/datarobot/drconfig.yaml, then we
-#' attempt to establish a connection to DataRobot when the package loads, so
-#' (if successful) this function does not need to be called.
-#'
-#' The function creates the environment variables "DataRobot_URL" and "DataRobot_Token" used by
-#' other functions to access the DataRobot modeling engine.
+#' This function initializes a DataRobot session. To use DataRobot, you must connect to
+#' your account. This can be done in three ways:
+#' \itemize{
+#'   \item by passing an \code{endpoint} and \code{token} directly to \code{ConnectToDataRobot}
+#'   \item by having a YAML config file in $HOME/.config/datarobot/drconfig.yaml
+#'   \item by setting DATAROBOT_API_ENDPOINT and DATAROBOT_API_TOKEN environment variables
+#' }
+#' The three methods of authentication are given priority in that order (explicitly passing
+#' parameters to the function will trump a YAML config file, which will trump the environment
+#' variables.)
+#' If you have a YAML config file or environment variables set, you will not need to
+#' pass any parameters to \code{ConnectToDataRobot} in order to connect.
 #'
 #' @param endpoint character. URL specifying the DataRobot server to be used.
 #'   It depends on DataRobot modeling engine implementation (cloud-based, on-prem...) you are using.
@@ -39,8 +44,12 @@ ConnectToDataRobot <- function(endpoint = NULL,
                                sslVerify = TRUE,
                                configPath = NULL
 ) {
+  #  Check environment variables
+  envEndpoint <- Sys.getenv("DATAROBOT_API_ENDPOINT", unset = NA)
+  envToken <- Sys.getenv("DATAROBOT_API_TOKEN", unset = NA)
+
   #  If the user provides a token, save it to the environment
-  #  variable DataRobot_Token and call GetProjectList to verify it
+  #  variable DATAROBOT_API_TOKEN and call GetProjectList to verify it
 
   haveToken <- !is.null(token)
   haveUsernamePassword <- (!is.null(username)) || (!is.null(password))
@@ -58,6 +67,8 @@ ConnectToDataRobot <- function(endpoint = NULL,
     ConnectWithUsernamePassword(endpoint, username, password)
   } else if (haveConfigPath) {
     ConnectWithConfigFile(configPath)
+  } else if (!is.na(envEndpoint) & !is.na(envToken)) {
+    ConnectWithToken(envEndpoint, envToken)
   } else {
     errorMsg <- "No authentication method provided."
     stop(strwrap(errorMsg), call. = FALSE)
@@ -117,8 +128,8 @@ ConnectWithUsernamePassword <- function(endpoint, username, password) {
 
 SaveConnectionEnvironmentVars <- function(endpoint, token) {
   message("Authentication token saved")
-  Sys.setenv(DataRobot_URL = endpoint)
-  Sys.setenv(DataRobot_Token = token)
+  Sys.setenv(DATAROBOT_API_ENDPOINT = endpoint)
+  Sys.setenv(DATAROBOT_API_TOKEN = token)
 }
 
 SaveUserAgentSuffix <- function(suffix) {
@@ -158,23 +169,23 @@ VersionWarning <- function() {
   if (clientVer$minor > serverVer$minor) {
     warMsg <-
       paste("Client version is ahead of server version, you may have incompatibilities")
-      warning(warMsg, call. = FALSE)
+    warning(warMsg, call. = FALSE)
   }
 }
 
 GetServerVersion <- function() {
-  dataRobotUrl <- Sys.getenv("DataRobot_URL")
+  dataRobotUrl <- Sys.getenv("DATAROBOT_API_ENDPOINT")
   errorMessage <-
     paste("Server did not reply with an API version. This may indicate the endpoint ", dataRobotUrl,
           "\n is misconfigured, or that the server API version precedes this version \n  ",
           "of the DataRobot client package and is likely incompatible.")
   ver <- tryCatch({routeString <- UrlJoin("version")
-                   modelInfo <- DataRobotGET(routeString, addUrl = TRUE)
-                  },
-                  ConfigError = function(e) {
-                    warning(errorMessage)
-                    ver <- NULL
-                 })
+  modelInfo <- DataRobotGET(routeString, addUrl = TRUE)
+  },
+  ConfigError = function(e) {
+    warning(errorMessage)
+    ver <- NULL
+  })
 }
 
 GetClientVersion <- function() {
