@@ -53,6 +53,9 @@ ListModelFeatures <- function(model) {
 #'     at an integer multiple of this value. NULL for features that are not time series eligible.
 #'   \item timeUnit character. For time series eligible features, the time unit covered by a
 #'     single time step, e.g. "HOUR", or NULL for features that are not time series eligible.
+#'   \item targetLeakage character. Whether a feature is considered to have target leakage or not.
+#'     A value of "SKIPPED_DETECTION" indicates that target leakage detection was not run on
+#'     the feature.
 #' }
 #' @examples
 #' \dontrun{
@@ -106,7 +109,8 @@ as.dataRobotFeatureInfo <- function(inList) {
                 "timeSeriesEligible",
                 "timeSeriesEligibilityReason",
                 "timeStep",
-                "timeUnit")
+                "timeUnit",
+                "targetLeakage")
   ApplySchema(inList, elements)
 }
 
